==> django_silica-0.1.40.tar.gz: django_silica-0.1.40/django_silica/templatetags/silica.py <==
from typing import Dict

import shortuuid

from django_silica.call_method_parser import parse_kwarg, InvalidKwarg
from django_silica.errors import ComponentNotValid
from django_silica.SilicaComponent import SilicaComponent
from django import template

register = template.Library()


def silica(parser, token):
    parts = token.split_contents()

    if len(parts) < 2:
        raise template.TemplateSyntaxError(
            "%r tag requires at least a single argument" % token.contents.split()[0]
        )

    component_name = parser.compile_filter(parts[1])

    kwargs = {}

    # pass any other kwargs to component create
    for arg in parts[2:]:
        try:
            kwarg = parse_kwarg(arg)
            kwargs.update(kwarg)
        except InvalidKwarg:
            pass

    return SilicaNode(component_name=component_name, kwargs=kwargs)


register.tag("silica", silica)


class SilicaNode(template.Node):
    def __init__(self, component_name, kwargs: Dict = {}):
        self.component_name = component_name
        self.kwargs = kwargs
        self.component_key = ""
        self.parent = None

    def render(self, context, **kwargs):
        request = context.get("request", None)

        resolved_kwargs = {}
        for key, value in self.kwargs.items():
            try:
                resolved_value = template.Variable(value).resolve(context)
                resolved_kwargs.update({key: resolved_value})
            except template.VariableDoesNotExist:
                resolved_kwargs.update({key: value})

        if "key" in resolved_kwargs:
            component_key = resolved_kwargs.pop("key")
        else:
            component_key = None

        if "lazy" in resolved_kwargs:
            lazy = resolved_kwargs.pop("lazy")
        else:
            lazy = False

        try:
            component_name = self.component_name.resolve(context)
        except AttributeError:
            raise ComponentNotValid(
                f"Component template is not valid: {self.component_name}."
            )

        resolved_kwargs.update({"lazy": lazy})

        component_id = shortuuid.uuid()

        self.view = SilicaComponent.create(
            component_id=component_id,
            component_name=component_name,
            component_key=component_key,
            kwargs=resolved_kwargs,
            request=request,
        )

        if request:

            # Oddly, django's request.GET will only either return dict (.items(), .dict()) where it will cut short list/multiples of one key
            # or .lists() where it will force all items as a list, even single values, but we do get the multiples.
            processed_params = {}

            for key, values in request.GET.lists():
                # Store the value directly if there's only one, or as a list if there are multiple
                processed_params[key] = values if len(values) > 1 else values[0]

            for key, value in processed_params.items():
                for query_param in self.view.query_params:
                    if isinstance(query_param, dict):
                        if query_param.get("as", query_param.get("param")) == key:
                            # TODO - Could this be firing twice for fresh page loads?
                            self.view.set_property(query_param.get("param"), value)
                            # setattr(self, query_param.get("param"), value)
                    else:
                        if query_param == key:
                            # TODO - Could this be firing twice for fresh page loads?
                            self.view.set_property(key, value)
                            # setattr(self, key, value)

            self.request = request

        if not lazy:
            self.view.mount()

        rendered_component = self.view.render(init_js=True, request=request)

        return rendered_component

==> django_silica-0.1.48.tar.gz: django_silica-0.1.48/django_silica/templatetags/silica.py <==
from typing import Dict

import shortuuid

from django_silica.utils import kwarg_as_dict
from django_silica.errors import ComponentNotValid
from django_silica.SilicaComponent import SilicaComponent
from django import template

register = template.Library()


def silica(parser, token):
    parts = token.split_contents()

    if len(parts) < 2:
        raise template.TemplateSyntaxError(
            "%r tag requires at least a single argument" % token.contents.split()[0]
        )

    component_name = parser.compile_filter(parts[1])

    kwargs = {}
    for arg in parts[2:]:
        try:
            kwarg = kwarg_as_dict(arg)
            kwargs.update(kwarg)
        except ValueError:
            pass

    return SilicaNode(component_name=component_name, kwargs=kwargs)


register.tag("silica", silica)


class SilicaNode(template.Node):
    def __init__(self, component_name, kwargs: Dict = {}):
        self.component_name = component_name
        self.kwargs = kwargs
        self.component_key = ""
        self.parent = None

    def render(self, context, **kwargs):
        request = context.get("request", None)

        resolved_kwargs = {}
        for key, value in self.kwargs.items():
            try:
                resolved_value = template.Variable(value).resolve(context)
                resolved_kwargs.update({key: resolved_value})
            except template.VariableDoesNotExist:
                resolved_kwargs.update({key: value})

        if "key" in resolved_kwargs:
            component_key = resolved_kwargs.pop("key")
        else:
            component_key = None

        if "lazy" in resolved_kwargs:
            lazy = resolved_kwargs.pop("lazy")
        else:
            lazy = False

        try:
            component_name = self.component_name.resolve(context)
        except AttributeError:
            raise ComponentNotValid(
                f"Component template is not valid: {self.component_name}."
            )

        resolved_kwargs.update({"lazy": lazy})

        component_id = shortuuid.uuid()

        self.view = SilicaComponent.create(
            component_id=component_id,
            component_name=component_name,
            component_key=component_key,
            kwargs=resolved_kwargs,
            request=request,
        )

        if request:

            # Oddly, django's request.GET will only either return dict (.items(), .dict()) where it will cut short list/multiples of one key
            # or .lists() where it will force all items as a list, even single values, but we do get the multiples.
            processed_params = {}

            for key, values in request.GET.lists():
                # Store the value directly if there's only one, or as a list if there are multiple
                processed_params[key] = values if len(values) > 1 else values[0]

            for key, value in processed_params.items():
                for query_param in self.view.query_params:
                    if isinstance(query_param, dict):
                        if query_param.get("as", query_param.get("param")) == key:
                            # TODO, should probably not allow dictionary key path setting, just limit to base attribute
                            self.view.set_property(query_param.get("param"), value, False)
                    else:
                        if query_param == key:
                            # TODO, should probably not allow dictionary key path setting, just limit to base attribute
                            self.view.set_property(key, value, False)

            self.request = request

        if not lazy:
            self.view.mount()

        rendered_component = self.view.render(init_js=True, request=request)

        return rendered_component
